@@ -25,26 +25,24 @@ class CreateFolderRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateFolder')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FolderPath(self):
+	def get_FolderPath(self): # String
 		return self.get_body_params().get('FolderPath')
 
-	def set_FolderPath(self,FolderPath):
+	def set_FolderPath(self, FolderPath):  # String
 		self.add_body_params('FolderPath', FolderPath)
-
-	def get_ProjectId(self):
+	def get_ProjectId(self): # Long
 		return self.get_body_params().get('ProjectId')
 
-	def set_ProjectId(self,ProjectId):
+	def set_ProjectId(self, ProjectId):  # Long
 		self.add_body_params('ProjectId', ProjectId)
-
-	def get_ProjectIdentifier(self):
+	def get_ProjectIdentifier(self): # String
 		return self.get_body_params().get('ProjectIdentifier')
 
-	def set_ProjectIdentifier(self,ProjectIdentifier):
-		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
\ No newline at end of file
+	def set_ProjectIdentifier(self, ProjectIdentifier):  # String
+		self.add_body_params('ProjectIdentifier', ProjectIdentifier)
